==> openjdk13-13.0.13_0+release+server.darwin_16.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_af.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_af extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "MXN", "MXN" },
            { "THB", "\u0e3f" },
            { "ZAR", "R" },
            { "aed", "Verenigde Arabiese Emirate dirham" },
            { "afn", "Afgaanse afgani" },
            { "all", "Albanese lek" },
            { "amd", "Armeense dram" },
            { "ang", "Nederlands-Antilliaanse gulde" },
            { "aoa", "Angolese kwanza" },
            { "ars", "Argentynse peso" },
            { "aud", "Australiese dollar" },
            { "awg", "Arubaanse floryn" },
            { "azn", "Azerbeidjaanse manat" },
            { "bam", "Bosnies-Herzegowiniese omskakelbare marka" },
            { "bbd", "Barbados-dollar" },
            { "bdt", "Bangladesjiese taka" },
            { "bgn", "Bulgaarse lev" },
            { "bhd", "Bahreinse dinar" },
            { "bif", "Burundiese frank" },
            { "bmd", "Bermuda-dollar" },
            { "bnd", "Broeneise dollar" },
            { "bob", "Boliviaanse boliviano" },
            { "brl", "Brasilliaanse reaal" },
            { "bsd", "Bahamiaanse dollar" },
            { "btn", "Bhoetanese ngoeltroem" },
            { "bwp", "Botswana pula" },
            { "byn", "Belo-Russiese roebel" },
            { "byr", "Belo-Russiese roebel (2000\u20132016)" },
            { "bzd", "Beliziese dollar" },
            { "cad", "Kanadese dollar" },
            { "cdf", "Kongolese frank" },
            { "chf", "Switserse frank" },
            { "clp", "Chileense peso" },
            { "cnh", "Chinese joean" },
            { "cny", "Sjinese joean renminbi" },
            { "cop", "Colombiaanse peso" },
            { "crc", "Costa Ricaanse col\u00f3n" },
            { "cuc", "Kubaanse omskakelbare peso" },
            { "cup", "Kubaanse peso" },
            { "cve", "Kaap Verdiese escudo" },
            { "czk", "Tsjeggiese kroon" },
            { "djf", "Djiboeti frank" },
            { "dkk", "Deense kroon" },
            { "dop", "Dominikaanse peso" },
            { "dzd", "Algeriese dinar" },
            { "egp", "Egiptiese pond" },
            { "ern", "Eritrese nakfa" },
            { "etb", "Etiopiese birr" },
            { "eur", "euro" },
            { "fjd", "Fidjiaanse dollar" },
            { "fkp", "Falkland-eilande pond" },
            { "gbp", "Britse pond" },
            { "gel", "Georgiese lari" },
            { "ghc", "Ghanese cedi (1979\u20132007)" },
            { "ghs", "Ghanese cedi" },
            { "gip", "Gibraltarese pond" },
            { "gmd", "Gambiese dalasi" },
            { "gnf", "Guinese frank" },
            { "gns", "Guinese syli" },
            { "gtq", "Guatemalaanse quetzal" },
            { "gyd", "Guyanese dollar" },
            { "hkd", "Hong Kong dollar" },
            { "hnl", "Hondurese lempira" },
            { "hrk", "Kroatiese kuna" },
            { "htg", "Ha\u00eftiaanse gourde" },
            { "huf", "Hongaarse florint" },
            { "idr", "Indonesiese roepia" },
            { "ils", "Israeliese nuwe sikkel" },
            { "inr", "Indiese roepee" },
            { "iqd", "Irakse dinar" },
            { "irr", "Iranse rial" },
            { "isk", "Yslandse kroon" },
            { "itl", "Italiaanse lier" },
            { "jmd", "Jamaikaanse dollar" },
            { "jod", "Jordaniese dinar" },
            { "jpy", "Japannese jen" },
            { "kes", "Keniaanse sjieling" },
            { "kgs", "Kirgisiese som" },
            { "khr", "Kambodjaanse riel" },
            { "kmf", "Comoraanse frank" },
            { "kpw", "Noord-Koreaanse won" },
            { "krw", "Suid-Koreaanse won" },
            { "kwd", "Koeweitse dinar" },
            { "kyd", "Cayman-eilande dollar" },
            { "kzt", "Kazakse tenge" },
            { "lak", "Laosiaanse kip" },
            { "lbp", "Lebanese pond" },
            { "lkr", "Sri Lankaanse roepee" },
            { "lrd", "Liberiese dollar" },
            { "lsl", "Lesotho loti" },
            { "ltl", "Litause litas" },
            { "lvl", "Lettiese lats" },
            { "lyd", "Libiese dinar" },
            { "mad", "Marokkaanse dirham" },
            { "mdl", "Moldowiese leu" },
            { "mga", "Malgassiese ariary" },
            { "mkd", "Macedoniese denar" },
            { "mmk", "Mianmese kyat" },
            { "mnt", "Mongoolse toegrik" },
            { "mop", "Macaose pataca" },
            { "mro", "Mauritaniese ouguiya (1973\u20132017)" },
            { "mru", "Mauritaniese ouguiya" },
            { "mur", "Mauritiaanse rupee" },
            { "mvr", "Malediviese rufia" },
            { "mwk", "Malawiese kwacha" },
            { "mxn", "Meksikaanse peso" },
            { "myr", "Maleisiese ringgit" },
            { "mzm", "Mosambiekse metical (1980\u20132006)" },
            { "mzn", "Mosambiekse metical" },
            { "nad", "Namibiese dollar" },
            { "ngn", "Nigeriese naira" },
            { "nio", "Nicaraguaanse c\u00f3rdoba" },
            { "nok", "Noorse kroon" },
            { "npr", "Nepalese roepee" },
            { "nzd", "Nieu-Seeland dollar" },
            { "omr", "Omaanse rial" },
            { "pab", "Panamese balboa" },
            { "pen", "Peruaanse sol" },
            { "pgk", "Papoea-Nieu-Guinese kina" },
            { "php", "Filippynse peso" },
            { "pkr", "Pakistanse roepee" },
            { "pln", "Poolse zloty" },
            { "pyg", "Paraguaanse guarani" },
            { "qar", "Katarrese rial" },
            { "ron", "Roemeense leu" },
            { "rsd", "Serbiese dinar" },
            { "rub", "Russiese roebel" },
            { "rwf", "Rwandiese frank" },
            { "sar", "Saoedi-Arabiese riyal" },
            { "sbd", "Salomonseilande dollar" },
            { "scr", "Seychellese rupee" },
            { "sdg", "Soedannese pond" },
            { "sdp", "Soedannese pond (1957\u20131998)" },
            { "sek", "Sweedse kroon" },
            { "sgd", "Singapoer dollar" },
            { "shp", "Sint Helena pond" },
            { "sll", "Sierra Leoniese leone" },
            { "sos", "Somaliese sjieling" },
            { "srd", "Surinaamse dollar" },
            { "ssp", "Suid-Soedanese pond" },
            { "std", "S\u00e3o Tom\u00e9 en Pr\u00edncipe dobra (1977\u20132017)" },
            { "stn", "S\u00e3o Tom\u00e9 en Pr\u00edncipe dobra" },
            { "syp", "Siriese pond" },
            { "szl", "Swazilandse lilangeni" },
            { "thb", "Thaise baht" },
            { "tjs", "Tadjikse roebel" },
            { "tmt", "Turkmeense manat" },
            { "tnd", "Tunisiese dinar" },
            { "top", "Tongaanse pa\u2019anga" },
            { "trl", "Turkse lier (1922\u20132005)" },
            { "try", "Turkse lier" },
            { "ttd", "Trinidad en Tobago dollar" },
            { "twd", "Nuwe Taiwanese dollar" },
            { "tzs", "Tanzaniese sjieling" },
            { "uah", "Oekra\u00efnse hriwna" },
            { "ugx", "Ugandese sjieling" },
            { "usd", "Amerikaanse dollar" },
            { "uyu", "Uruguaanse peso" },
            { "uzs", "Oezbekiese som" },
            { "vef", "Venezolaanse bolivar" },
            { "ves", "Venezolaanse Bol\u00edvar" },
            { "vnd", "Vi\u00ebtnamese dong" },
            { "vuv", "Vanuatuse vatu" },
            { "wst", "Samoaanse tala" },
            { "xaf", "CFA frank BEAC" },
            { "xcd", "Oos-Karibbiese dollar" },
            { "xof", "CFA frank BCEAO" },
            { "xpf", "CFP-frank" },
            { "xxx", "onbekende geldeenheid" },
            { "yer", "Jemenitiese rial" },
            { "zar", "Suid-Afrikaanse rand" },
            { "zmk", "Zambiese kwacha (1968\u20132012)" },
            { "zmw", "Zambiese kwacha" },
            { "zwd", "Zimbabwiese dollar" },
        };
        return data;
    }
}

==> openjdk15-15.0.9_0+release+server.darwin_16.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_af.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_af extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CAD", "CAD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXN", "MXN" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "USD", "USD" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "R" },
            { "ZMW", "ZMW" },
            { "aed", "Verenigde Arabiese Emirate-dirham" },
            { "afn", "Afgaanse afgani" },
            { "all", "Albanese lek" },
            { "amd", "Armeense dram" },
            { "ang", "Nederlands-Antilliaanse gulde" },
            { "aoa", "Angolese kwanza" },
            { "ars", "Argentynse peso" },
            { "aud", "Australiese dollar" },
            { "awg", "Arubaanse floryn" },
            { "azn", "Azerbeidjaanse manat" },
            { "bam", "Bosnies-Herzegowiniese omskakelbare marka" },
            { "bbd", "Barbados-dollar" },
            { "bdt", "Bangladesjiese taka" },
            { "bgn", "Bulgaarse lev" },
            { "bhd", "Bahreinse dinar" },
            { "bif", "Burundiese frank" },
            { "bmd", "Bermuda-dollar" },
            { "bnd", "Broeneise dollar" },
            { "bob", "Boliviaanse boliviano" },
            { "brl", "Brasilliaanse reaal" },
            { "bsd", "Bahamiaanse dollar" },
            { "btn", "Bhoetanese ngoeltroem" },
            { "bwp", "Botswana-pula" },
            { "byn", "Belarusiese roebel" },
            { "byr", "Belo-Russiese roebel (2000\u20132016)" },
            { "bzd", "Beliziese dollar" },
            { "cad", "Kanadese dollar" },
            { "cdf", "Kongolese frank" },
            { "chf", "Switserse frank" },
            { "clp", "Chileense peso" },
            { "cnh", "Chinese joean (buiteland)" },
            { "cny", "Chinese joean" },
            { "cop", "Colombiaanse peso" },
            { "crc", "Costa Ricaanse col\u00f3n" },
            { "cuc", "Kubaanse omskakelbare peso" },
            { "cup", "Kubaanse peso" },
            { "cve", "Kaap Verdiese escudo" },
            { "czk", "Tsjeggiese kroon" },
            { "djf", "Djiboeti-frank" },
            { "dkk", "Deense kroon" },
            { "dop", "Dominikaanse peso" },
            { "dzd", "Algeriese dinar" },
            { "egp", "Egiptiese pond" },
            { "ern", "Eritrese nakfa" },
            { "etb", "Etiopiese birr" },
            { "eur", "euro" },
            { "fjd", "Fidjiaanse dollar" },
            { "fkp", "Falkland-eilandse pond" },
            { "gbp", "Britse pond" },
            { "gel", "Georgiese lari" },
            { "ghc", "Ghanese cedi (1979\u20132007)" },
            { "ghs", "Ghanese cedi" },
            { "gip", "Gibraltarese pond" },
            { "gmd", "Gambiese dalasi" },
            { "gnf", "Guinese frank" },
            { "gns", "Guinese syli" },
            { "gtq", "Guatemalaanse quetzal" },
            { "gyd", "Guyanese dollar" },
            { "hkd", "Hongkongse dollar" },
            { "hnl", "Hondurese lempira" },
            { "hrk", "Kroatiese kuna" },
            { "htg", "Ha\u00eftiaanse gourde" },
            { "huf", "Hongaarse florint" },
            { "idr", "Indonesiese roepia" },
            { "ils", "Israeliese nuwe sikkel" },
            { "inr", "Indiese roepee" },
            { "iqd", "Irakse dinar" },
            { "irr", "Iranse rial" },
            { "isk", "Yslandse kroon" },
            { "itl", "Italiaanse lier" },
            { "jmd", "Jamaikaanse dollar" },
            { "jod", "Jordaniese dinar" },
            { "jpy", "Japannese jen" },
            { "kes", "Keniaanse sjieling" },
            { "kgs", "Kirgisiese som" },
            { "khr", "Kambodjaanse riel" },
            { "kmf", "Comoraanse frank" },
            { "kpw", "Noord-Koreaanse won" },
            { "krw", "Suid-Koreaanse won" },
            { "kwd", "Koeweitse dinar" },
            { "kyd", "Cayman-eilandse dollar" },
            { "kzt", "Kazakse tenge" },
            { "lak", "Laosiaanse kip" },
            { "lbp", "Libanese pond" },
            { "lkr", "Sri Lankaanse roepee" },
            { "lrd", "Liberiese dollar" },
            { "lsl", "Lesotho loti" },
            { "ltl", "Litause litas" },
            { "lvl", "Lettiese lats" },
            { "lyd", "Libiese dinar" },
            { "mad", "Marokkaanse dirham" },
            { "mdl", "Moldowiese leu" },
            { "mga", "Malgassiese ariary" },
            { "mkd", "Macedoniese denar" },
            { "mmk", "Mianmese kyat" },
            { "mnt", "Mongoolse toegrik" },
            { "mop", "Macaose pataca" },
            { "mro", "Mauritaniese ouguiya (1973\u20132017)" },
            { "mru", "Mauritaniese ouguiya" },
            { "mur", "Mauritiaanse roepee" },
            { "mvr", "Malediviese rufia" },
            { "mwk", "Malawiese kwacha" },
            { "mxn", "Meksikaanse peso" },
            { "myr", "Maleisiese ringgit" },
            { "mzm", "Mosambiekse metical (1980\u20132006)" },
            { "mzn", "Mosambiekse metical" },
            { "nad", "Namibiese dollar" },
            { "ngn", "Nigeriese naira" },
            { "nio", "Nicaraguaanse c\u00f3rdoba" },
            { "nok", "Noorse kroon" },
            { "npr", "Nepalese roepee" },
            { "nzd", "Nieu-Seelandse dollar" },
            { "omr", "Omaanse rial" },
            { "pab", "Panamese balboa" },
            { "pen", "Peruaanse sol" },
            { "pgk", "Papoea-Nieu-Guinese kina" },
            { "php", "Filippynse peso" },
            { "pkr", "Pakistanse roepee" },
            { "pln", "Poolse zloty" },
            { "pyg", "Paraguaanse guarani" },
            { "qar", "Katarrese rial" },
            { "ron", "Roemeense leu" },
            { "rsd", "Serwiese dinar" },
            { "rub", "Russiese roebel" },
            { "rwf", "Rwandese frank" },
            { "sar", "Saoedi-Arabiese riyal" },
            { "sbd", "Salomonseilandse dollar" },
            { "scr", "Seychellese roepee" },
            { "sdg", "Soedannese pond" },
            { "sdp", "Soedannese pond (1957\u20131998)" },
            { "sek", "Sweedse kroon" },
            { "sgd", "Singapoer-dollar" },
            { "shp", "Sint Helena-pond" },
            { "sll", "Sierra Leoniese leone" },
            { "sos", "Somaliese sjieling" },
            { "srd", "Surinaamse dollar" },
            { "ssp", "Suid-Soedanese pond" },
            { "std", "S\u00e3o Tom\u00e9 en Pr\u00edncipe dobra (1977\u20132017)" },
            { "stn", "S\u00e3o Tom\u00e9 en Pr\u00edncipe-dobra" },
            { "syp", "Siriese pond" },
            { "szl", "Swazilandse lilangeni" },
            { "thb", "Thaise baht" },
            { "tjs", "Tadjikse somoni" },
            { "tmt", "Turkmeense manat" },
            { "tnd", "Tunisiese dinar" },
            { "top", "Tongaanse pa\u2019anga" },
            { "trl", "Turkse lier (1922\u20132005)" },
            { "try", "Turkse lira" },
            { "ttd", "Trinidad en Tobago-dollar" },
            { "twd", "Nuwe Taiwanese dollar" },
            { "tzs", "Tanzaniese sjieling" },
            { "uah", "Oekra\u00efnse hriwna" },
            { "ugx", "Ugandese sjieling" },
            { "usd", "VSA-dollar" },
            { "uyu", "Uruguaanse peso" },
            { "uzs", "Oezbekiese som" },
            { "vef", "Venezolaanse bolivar" },
            { "ves", "Venezolaanse bol\u00edvar" },
            { "vnd", "Vi\u00ebtnamese dong" },
            { "vuv", "Vanuatuse vatu" },
            { "wst", "Samoaanse tala" },
            { "xaf", "Sentraal Afrikaanse CFA-frank" },
            { "xcd", "Oos-Karibiese dollar" },
            { "xof", "Wes-Afrikaanse CFA-frank" },
            { "xpf", "CFP-frank" },
            { "xxx", "onbekende geldeenheid" },
            { "yer", "Jemenitiese rial" },
            { "zar", "Suid-Afrikaanse rand" },
            { "zmk", "Zambiese kwacha (1968\u20132012)" },
            { "zmw", "Zambiese kwacha" },
            { "zwd", "Zimbabwiese dollar" },
        };
        return data;
    }
}
